@@ -29,14 +29,6 @@ $arr_tips = array
  . "reckognize them as belonging to this WebBox.",
 
  "There must not be two WebBox-es in the same web application with "
- . "the same ID!",
-
- "The framework tags are case sensitive, e.g. the framework will "
- . "reckognize the tag 'WebBox', however will not reckognize "
- . "the tag 'webbox'.",
-
- "The framework tag attributes are case sensitive, e.g. the framework will "
- . "reckognize the attribute 'ID' of the tag WebBox, however will not "
- . "reckognize the attribute 'id' of the tag WebBox."
+ . "the same ID!"
  );
 ?>
\ No newline at end of file
