@@ -19,6 +19,9 @@ along with phpWebApp; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA  
 */
 
+$file = $_REQUEST['file'];
+$lines = $_REQUEST['lines'];
+$highlights = $_REQUEST['highlights'];
 
 include "webapp.php";
 
