@@ -23,9 +23,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //constants of the paths in the application
 define("WEBAPP_PATH",   UP_PATH."web_app/");
 
-define("GRAPHICS",      APP_URL."graphics/");
-define("TPL_PATH",      APP_PATH."templates/");
-define("WOBJ_PATH",     APP_PATH."webobjects/");
+define("GRAPHICS",      "graphics/");
+define("TPL_PATH",      "templates/");
+define("WOBJ_PATH",     "webobjects/");
 
 //define paths and URLs of the sample applications
 define("SAMPLE_PATH",   UP_PATH."empty-sample/");
