@@ -4,7 +4,7 @@
 /** @package sample-application */
 /** */
 //constants of the paths in the application
-define("WEBAPP_PATH",   APP_PATH."../web_app/");
+define("WEBAPP_PATH",   UP_PATH."web_app/");
 define("GRAPHICS",      APP_URL."graphics/");
 define("TPL_PATH",      APP_PATH."templates/");
 define("TPL_URL",       APP_URL."templates/");
